==> at.bestsolution.rsd.rt.server.ejb.opentracing-1.0.0-20210708.110715-328-sources.jar: at/bestsolution/rsd/rt/server/ejb/opentracing/OpenTracingServerInterceptor.java <==
package at.bestsolution.rsd.rt.server.ejb.opentracing;

import java.lang.reflect.Method;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;
import java.util.Optional;
import java.util.ServiceLoader;

import javax.interceptor.AroundInvoke;
import javax.interceptor.Interceptor;
import javax.interceptor.InvocationContext;

import org.eclipse.microprofile.config.ConfigProvider;

import at.bestsolution.rsd.rt.ServiceProviderSystem;
import at.bestsolution.rsd.rt.opentracing.TraceProvider;
import at.bestsolution.rsd.rt.opentracing.Traced;
import io.opentracing.Scope;
import io.opentracing.SpanContext;
import io.opentracing.Tracer;
import io.opentracing.propagation.Format;
import io.opentracing.propagation.TextMap;
import io.opentracing.tag.Tags;
import io.opentracing.util.GlobalTracer;

@Traced
@Interceptor
public class OpenTracingServerInterceptor {
	// Use same ID as https://github.com/opentracing-contrib/java-ejb to integrate nicely with EJBs
	// using this strategy
	public static final String SPAN_CONTEXT = "__opentracing_span_context";
	private volatile Tracer tracer;

	private String getTraceProviderId() {
		return ConfigProvider.getConfig().getOptionalValue("rsd.opentracing.provider.id", String.class)
				.orElse("jaeger");
	}

	private Tracer getActiveTracer() {
		Tracer localTracer = tracer;
		if (localTracer == null) {
			synchronized (this) {
				localTracer = tracer;
				if (localTracer == null) {
					ServiceProviderSystem serviceProviderSystem = ServiceLoader.load(ServiceProviderSystem.class).iterator().next();
					List<TraceProvider> serviceList = serviceProviderSystem.lookupServices(TraceProvider.class);
					if (!serviceList.isEmpty()) {
						String providerId = getTraceProviderId();

						Optional<TraceProvider> provider = serviceList.stream()
							.filter( pr -> providerId.equals(pr.getId()))
							.findFirst();

						if( provider.isPresent() ) {
							tracer = localTracer = provider.get().getTracer();
						} else {
							tracer = localTracer = serviceList.get(0).getTracer();
						}
					} else {
						tracer = localTracer = GlobalTracer.get();
					}
				}
			}
		}

		return localTracer;
	}

	@AroundInvoke
	public Object wrap(InvocationContext context) throws Exception {
		Method method = context.getMethod();
		Class<?> owner = method.getDeclaringClass();

		boolean shouldTrace = true;
		String operationName = "";

		if (owner.isAnnotationPresent(Traced.class)) {
			Traced annotation = owner.getAnnotation(Traced.class);
			shouldTrace = annotation.value();
			operationName = annotation.operationName();
		}

		if (method.isAnnotationPresent(Traced.class)) {
			Traced annotation = method.getAnnotation(Traced.class);
			shouldTrace = annotation.value();
			operationName = annotation.operationName();
		}

		if (shouldTrace) {
			if (operationName == null || operationName.trim().isEmpty()) {
				operationName = method.getName();
			}
//			System.err.println("Tracer-Type-Id: " + context.getContextData().get("__rsd_trace-provider-id"));
			return traceCall(getActiveTracer(), operationName, context);
		} else {
			return context.proceed();
		}
	}

	private static Object traceCall(Tracer tracer, String operationName, InvocationContext context) throws Exception {
//		System.err.println("Context: " + context);
//		System.err.println("Context-Data: " + context.getContextData());
//		System.err.println("Active-Span: " + tracer.activeSpan());
//
		Tracer.SpanBuilder spanBuilder = tracer.buildSpan(operationName);
		spanBuilder = spanBuilder.withTag(Tags.COMPONENT.getKey(), "ejb");
		spanBuilder = spanBuilder.withTag("ejb.bean", context.getMethod().getDeclaringClass().getName());
		spanBuilder = spanBuilder.withTag(Tags.SPAN_KIND.getKey(), Tags.SPAN_KIND_SERVER);



//		Object possibleCtx = context.getContextData().get(SPAN_CONTEXT);
//		if( possibleCtx instanceof SpanContext ) {
//			spanBuilder = spanBuilder.asChildOf((SpanContext) possibleCtx);
//		} else {
			Object object = context.getContextData().get("__rsd_trace-span-context");

			if( object instanceof Map ) {
				Map<String, String> spanContext = (Map<String, String>)object;
				SpanContext parentContext = tracer.extract(Format.Builtin.TEXT_MAP, new TextMap() {

					@Override
					public void put(String key, String value) {
						throw new IllegalStateException("Only called when injecting");
					}

					@Override
					public Iterator<Entry<String, String>> iterator() {
						return spanContext.entrySet().iterator();
					}
				});
				spanBuilder = spanBuilder.asChildOf(parentContext);
			} else {
				System.err.println("ROOT SPAN CREATED");
			}
//		}
//
		try (Scope scope = spanBuilder.startActive(true)) {
			context.getContextData().put(SPAN_CONTEXT, scope.span().context());
			return context.proceed();
		} finally {
		}
	}
}

==> at.bestsolution.rsd.rt.server.ejb.opentracing-1.0.0-20210722.104619-329-sources.jar: at/bestsolution/rsd/rt/server/ejb/opentracing/OpenTracingServerInterceptor.java <==
package at.bestsolution.rsd.rt.server.ejb.opentracing;

import java.lang.reflect.Method;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;
import java.util.Optional;
import java.util.ServiceLoader;

import javax.interceptor.AroundInvoke;
import javax.interceptor.Interceptor;
import javax.interceptor.InvocationContext;

import org.eclipse.microprofile.config.ConfigProvider;

import at.bestsolution.rsd.rt.ServiceProviderSystem;
import at.bestsolution.rsd.rt.opentracing.TraceProvider;
import at.bestsolution.rsd.rt.opentracing.Traced;
import io.opentracing.Scope;
import io.opentracing.Span;
import io.opentracing.SpanContext;
import io.opentracing.Tracer;
import io.opentracing.propagation.Format;
import io.opentracing.propagation.TextMap;
import io.opentracing.tag.Tags;
import io.opentracing.util.GlobalTracer;

@Traced
@Interceptor
public class OpenTracingServerInterceptor {
	// Use same ID as https://github.com/opentracing-contrib/java-ejb to integrate nicely with EJBs
	// using this strategy
	public static final String SPAN_CONTEXT = "__opentracing_span_context";
	private volatile Tracer tracer;

	private String getTraceProviderId() {
		return ConfigProvider.getConfig().getOptionalValue("rsd.opentracing.provider.id", String.class)
				.orElse("jaeger");
	}

	private Tracer getActiveTracer() {
		Tracer localTracer = tracer;
		if (localTracer == null) {
			synchronized (this) {
				localTracer = tracer;
				if (localTracer == null) {
					ServiceProviderSystem serviceProviderSystem = ServiceLoader.load(ServiceProviderSystem.class).iterator().next();
					List<TraceProvider> serviceList = serviceProviderSystem.lookupServices(TraceProvider.class);
					if (!serviceList.isEmpty()) {
						String providerId = getTraceProviderId();

						Optional<TraceProvider> provider = serviceList.stream()
							.filter( pr -> providerId.equals(pr.getId()))
							.findFirst();

						if( provider.isPresent() ) {
							tracer = localTracer = provider.get().getTracer();
						} else {
							tracer = localTracer = serviceList.get(0).getTracer();
						}
					} else {
						tracer = localTracer = GlobalTracer.get();
					}
				}
			}
		}

		return localTracer;
	}

	@AroundInvoke
	public Object wrap(InvocationContext context) throws Exception {
		Method method = context.getMethod();
		Class<?> owner = method.getDeclaringClass();

		boolean shouldTrace = true;
		String operationName = "";

		if (owner.isAnnotationPresent(Traced.class)) {
			Traced annotation = owner.getAnnotation(Traced.class);
			shouldTrace = annotation.value();
			operationName = annotation.operationName();
		}

		if (method.isAnnotationPresent(Traced.class)) {
			Traced annotation = method.getAnnotation(Traced.class);
			shouldTrace = annotation.value();
			operationName = annotation.operationName();
		}

		if (shouldTrace) {
			if (operationName == null || operationName.trim().isEmpty()) {
				operationName = method.getName();
			}
//			System.err.println("Tracer-Type-Id: " + context.getContextData().get("__rsd_trace-provider-id"));
			return traceCall(getActiveTracer(), operationName, context);
		} else {
			return context.proceed();
		}
	}

	private static Object traceCall(Tracer tracer, String operationName, InvocationContext context) throws Exception {
//		System.err.println("Context: " + context);
//		System.err.println("Context-Data: " + context.getContextData());
//		System.err.println("Active-Span: " + tracer.activeSpan());
//
		Tracer.SpanBuilder spanBuilder = tracer.buildSpan(operationName);
		spanBuilder = spanBuilder.withTag(Tags.COMPONENT.getKey(), "ejb");
		spanBuilder = spanBuilder.withTag("ejb.bean", context.getMethod().getDeclaringClass().getName());
		spanBuilder = spanBuilder.withTag(Tags.SPAN_KIND.getKey(), Tags.SPAN_KIND_SERVER);



//		Object possibleCtx = context.getContextData().get(SPAN_CONTEXT);
//		if( possibleCtx instanceof SpanContext ) {
//			spanBuilder = spanBuilder.asChildOf((SpanContext) possibleCtx);
//		} else {
			Object object = context.getContextData().get("__rsd_trace-span-context");

			if( object instanceof Map ) {
				Map<String, String> spanContext = (Map<String, String>)object;
				SpanContext parentContext = tracer.extract(Format.Builtin.TEXT_MAP, new TextMap() {

					@Override
					public void put(String key, String value) {
						throw new IllegalStateException("Only called when injecting");
					}

					@Override
					public Iterator<Entry<String, String>> iterator() {
						return spanContext.entrySet().iterator();
					}
				});
				spanBuilder = spanBuilder.asChildOf(parentContext);
			} else {
				System.err.println("ROOT SPAN CREATED");
			}
//		}
//
		Span span = spanBuilder.start();
		try (Scope scope = tracer.activateSpan(span)) {
			context.getContextData().put(SPAN_CONTEXT, span.context());
			return context.proceed();
		} finally {
		}
	}
}
